@@ -21,7 +21,7 @@ func TestReadAll(t *testing.T) {
 		t.Error("OUCH")
 	}
 	s := segment{4176, 4951, file}
-	kf := newKeyFinder([]uint{7}, nil)
+	kf := newKeyFinder([]uint{7}, nil, false)
 	ch := make(chan segmentResult)
 	f := filters{nil, nil, nil}
 	go readSegment(&s, &f, kf, ch)
@@ -68,7 +68,7 @@ func TestReadSegmentFiltering(t *testing.T) {
 		t.Error("config!")
 	}
 
-	tmpName := fmt.Sprintf("/tmp/tf-%d", os.Getpid())
+	tmpName := fmt.Sprintf("/tmp/topfew-%d", os.Getpid())
 	tmpfile, err := os.Create(tmpName)
 	if err != nil {
 		t.Fatal("can't make tmpfile: " + err.Error())
@@ -77,7 +77,7 @@ func TestReadSegmentFiltering(t *testing.T) {
 	_, _ = fmt.Fprint(tmpfile, input)
 	_ = tmpfile.Close()
 	counter := newCounter(10)
-	err = readFileInSegments(tmpName, &c.filter, counter, newKeyFinder(c.fields, nil), 1)
+	err = readFileInSegments(tmpName, &c.filter, counter, newKeyFinder(c.fields, nil, false), 1)
 	if err != nil {
 		t.Error("Run? " + err.Error())
 	}
@@ -90,7 +90,7 @@ func TestReadSegmentFiltering(t *testing.T) {
 // ErrBufferFull condition, had to create lines 80k long to execute that, so rather than clutter
 // up the filesystem with this junk, we create them synthetically
 func TestVeryLongLines(t *testing.T) {
-	tmpName := fmt.Sprintf("/tmp/tf-%d", os.Getpid())
+	tmpName := fmt.Sprintf("/tmp/topfew-%d", os.Getpid())
 	tmpfile, err := os.Create(tmpName)
 	if err != nil {
 		t.Fatal("can't make tmpfile: " + err.Error())
@@ -110,7 +110,7 @@ func TestVeryLongLines(t *testing.T) {
 	}
 	_ = tmpfile.Close()
 	counter := newCounter(10)
-	err = readFileInSegments(tmpName, &filters{}, counter, newKeyFinder(nil, nil), 1)
+	err = readFileInSegments(tmpName, &filters{}, counter, newKeyFinder(nil, nil, false), 1)
 	if err != nil {
 		t.Fatal("Failed to read long-lines file")
 	}
