@@ -11,7 +11,7 @@ func main() {
 
 	config, err := topfew.Configure(os.Args[1:]) // skip whatever go puts in os.Args[0]
 	if err != nil {
-		fmt.Println("Problem (tf -h for help): " + err.Error())
+		fmt.Println("Problem (topfew -h for help): " + err.Error())
 		os.Exit(1)
 	}
 
